@@ -3,6 +3,7 @@
 import json
 from resources.models.helper import rest_post_json_call
 from resources.models.helper import rest_get_call
+from resources.models.helper import TestType
 
 
 class BenchmarkResource(object):
@@ -14,11 +15,25 @@ class BenchmarkResource(object):
         self.time_out = time_out
 
     def start_benchmark_test(self, parameters=None):
-        # data = {"parameters": {"type":"fio", "test_name":"name1", "blocksize":"128k", "iodepth":"8", "runtime": "30", "size":"100%", "rw": "read", "numjobs":"1"}}
+        benchmark_parameter = {
+            "type": TestType.TestBenchmark,
+            "parameters": parameters
+        }
         url_ = "http://{0}:{1}/benchmark".format(self.host, self.port)
-        result = rest_post_json_call(url_, self.session, json.dumps(parameters), self.time_out)
+        result = rest_post_json_call(url_, self.session, json.dumps(benchmark_parameter), self.time_out)
         return result["resource"]
 
+    def start_benchmark_group_test(self, test_name, parameters=None):
+        group_parameter = {
+            "type": TestType.TestBenchmarkGroup,
+            "test_name": test_name,
+            "parameters": parameters
+        }
+        url_ = "http://{0}:{1}/benchmark".format(self.host, self.port)
+        result = rest_post_json_call(url_, self.session, json.dumps(group_parameter), self.time_out)
+        return result["resource"]
+
+
     def get_async_result(self, key):
         url_ = "http://{0}:{1}/benchmark/results/{2}".format(self.host, self.port, key)
         result = rest_get_call(url_, self.session, self.time_out)
